% Initializes FAMILY BN 
% the network will be used in family_learn.m

% set BN toolbox path first (if not already done)
% cd /mypath/BN/FullBNT-1.0.4/
% addpath(genpathKPM(pwd))

% variable/node numbering (NB: nodes must be topologically sorted)
FO = 1; BP = 2; LO = 3; DO = 4; HB = 5;
N=5;

% variable names
names = {'fo','bp','lo','do','hb'};

% dag incidence matrix -- initialization
dag = zeros(5,5);

% dag incidence matrix -- the individual edges
% gives the network structure
dag(FO,LO)=1;
dag([FO BP],DO)=1;
dag(DO,HB) = 1;

% show the dag 
draw_graph(dag, names);

% determine the node sizes, i.e. the number of values they can take
% (family problem is binary -- all the variables are binary)
node_sizes = 2*ones(1,5);

% initialize the bnet object
bnet_orig = mk_bnet(dag, node_sizes, 'names', names);

% the network variables can be accessed through their names, e.g.:
FO = bnet_orig.names('fo');

% specification of network parameters, conditional probability tables for the individual nodes
% the first value is regarded as T (true~1), the second as F (false~2) -- an arbitrary choice, needs top be kept in all the problem
% (BNT numbers the binary node values with indeces 1 and 2, the usual notation T~1, F~0 cannot be used)
bnet_orig.CPD{FO} = tabular_CPD(bnet_orig, FO, 'CPT', [0.15 0.85]');
bnet_orig.CPD{BP} = tabular_CPD(bnet_orig, BP, 'CPT', [0.01 0.99]');

% FO LO prob
% ----------
% T  T   0.6   P(LO=T|FO=T) = 0.6
% F  T   0.05  P(LO=T|FO=F) = 0.05
% T  F   0.4   P(LO=F|FO=T) = 0.4
% F  F   0.05  P(LO=F|FO=F) = 0.95
bnet_orig.CPD{LO} = tabular_CPD(bnet_orig, LO, 'CPT', [0.6 0.05 0.4 0.95]');

% FO BP DO prob
% --------------
% T  T  T  0.99   P(DO=T|FO=T,BP=T) = 0.99
% F  T  T  0.97   P(DO=T|FO=F,BP=T) = 0.97
% T  F  T  0.9    P(DO=T|FO=T,BP=F) = 0.9
% F  F  T  0.3    P(DO=T|FO=F,BP=F) = 0.3
% T  T  F  0.01   P(DO=F|FO=T,BP=T) = 0.01
% F  T  F  0.03   P(DO=F|FO=F,BP=T) = 0.03
% T  F  F  0.1    P(DO=F|FO=T,BP=F) = 0.1
% F  F  F  0.7    P(DO=F|FO=F,BP=F) = 0.7
bnet_orig.CPD{DO} = tabular_CPD(bnet_orig, DO, 'CPT', [0.99 0.97 0.9 0.3 0.01 0.03 0.1 0.7]');
bnet_orig.CPD{HB} = tabular_CPD(bnet_orig, HB, 'CPT', [0.7 0.01 0.3 0.99]');

% save bnet to external file for future use
save bnet_orig bnet_orig;